@@ -1,12 +1,12 @@
-#!/usr/bin/python2.7
+#!/usr/bin/python3
 # coding: utf-8
 #
 # Univention Management Console module:
 #  System Diagnosis UMC module
 #
-# Copyright 2017 Univention GmbH
+# Copyright 2017-2021 Univention GmbH
 #
-# http://www.univention.de/
+# https://www.univention.de/
 #
 # All rights reserved.
 #
@@ -29,7 +29,7 @@
 # You should have received a copy of the GNU Affero General Public
 # License with the Debian GNU/Linux or Univention distribution in file
 # /usr/share/common-licenses/AGPL-3; if not, see
-# <http://www.gnu.org/licenses/>.
+# <https://www.gnu.org/licenses/>.
 
 import os
 import ldap
@@ -52,6 +52,7 @@ _ = Translation('univention-management-console-module-diagnostic').translate
 
 title = _('Check Samba replication status for errors')
 description = _('No errors found.'),
+run_descr = ['This can be checked by running: samba-tool drs showrepl']
 
 
 class DRSUAPI(object):
@@ -88,8 +89,7 @@ class DRSUAPI(object):
 		return (info_type, info)
 
 	def neighbours(self):
-		for replica_info_direction in (drsuapi.DRSUAPI_DS_REPLICA_INFO_NEIGHBORS,
-						drsuapi.DRSUAPI_DS_REPLICA_INFO_REPSTO):
+		for replica_info_direction in (drsuapi.DRSUAPI_DS_REPLICA_INFO_NEIGHBORS, drsuapi.DRSUAPI_DS_REPLICA_INFO_REPSTO):
 			(info_type, info) = self._replica_info(replica_info_direction)
 			for neighbour in info.array:
 				yield (replica_info_direction, neighbour)
@@ -118,8 +118,7 @@ class ReplicationProblem(Exception):
 		exploded = ldap.dn.str2dn(dn)
 		if len(exploded) >= 5:
 			(first, second, third, fourth, fifth) = exploded[:5]
-			valid_ntds_dn = all((first[0][1] == 'NTDS Settings',
-				third[0][1] == 'Servers', fifth[0][1] == 'Sites'))
+			valid_ntds_dn = all((first[0][1] == 'NTDS Settings', third[0][1] == 'Servers', fifth[0][1] == 'Sites'))
 			if valid_ntds_dn:
 				return '{}/{}'.format(fourth[0][1], second[0][1])
 		return dn
@@ -129,16 +128,14 @@ class InboundReplicationProblem(ReplicationProblem):
 	def __str__(self):
 		msg = _('Inbound {nc!r}: error during DRS replication from {source} ({estring})')
 		source = self._parse_ntds_dn(self.neighbour.source_dsa_obj_dn)
-		return msg.format(nc=self.neighbour.naming_context_dn.encode(),
-			source=source, estring=self.estring)
+		return msg.format(nc=self.neighbour.naming_context_dn.encode(), source=source, estring=self.estring)
 
 
 class OutboundReplicationProblem(ReplicationProblem):
 	def __str__(self):
 		msg = _('Outbound {nc!r}: error during DRS replication to {source} ({estring})')
 		source = self._parse_ntds_dn(self.neighbour.source_dsa_obj_dn)
-		return msg.format(nc=self.neighbour.naming_context_dn.encode(),
-			source=source, estring=self.estring)
+		return msg.format(nc=self.neighbour.naming_context_dn.encode(), source=source, estring=self.estring)
 
 
 def run(_umc_instance):
